@@ -12,6 +12,7 @@ import dataclasses
 import itertools
 import math
 import sys
+import time
 from contextlib import contextmanager, nullcontext
 from random import Random
 from typing import Optional
@@ -32,6 +33,7 @@ from hypothesis.database import InMemoryExampleDatabase
 from hypothesis.errors import (
     BackendCannotProceed,
     Flaky,
+    FlakyBackendFailure,
     HypothesisException,
     HypothesisWarning,
     InvalidArgument,
@@ -780,3 +782,18 @@ def test_provider_conformance(provider):
     run_conformance_test(
         provider, settings=settings(max_examples=20, stateful_step_count=20)
     )
+
+
+# see https://github.com/HypothesisWorks/hypothesis/issues/4462 and discussion
+# in https://github.com/HypothesisWorks/hypothesis/pull/4470
+def test_backend_deadline_exceeded_raised_as_flaky_backend_failure():
+    with temp_register_backend("trivial", TrivialProvider):
+
+        @given(st.integers())
+        @settings(backend="trivial", database=None)
+        def f(n):
+            if isinstance(current_build_context().data.provider, TrivialProvider):
+                time.sleep(1)
+
+        with pytest.raises(FlakyBackendFailure):
+            f()
